﻿/*
 * Copyright (c) 2020 ETH Zürich, Educational Development and Technology (LET)
 * 
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

namespace SafeExamBrowser.SystemComponents.Contracts
{
	/// <summary>
	/// Provides access to information about the computer system.
	/// </summary>
	public interface ISystemInfo
	{
		/// <summary>
		/// Reveals whether the computer system contains a battery.
		/// </summary>
		bool HasBattery { get; }

		/// <summary>
		/// The manufacturer name of the computer system.
		/// </summary>
		string Manufacturer { get; }

		/// <summary>
		/// The model name of the computer system.
		/// </summary>
		string Model { get; }

		/// <summary>
		/// The machine name of the computer system.
		/// </summary>
		string Name { get; }

		/// <summary>
		/// Reveals the version of the currently running operating system.
		/// </summary>
		OperatingSystem OperatingSystem { get; }

		/// <summary>
		/// Provides detailed version information about the currently running operating system.
		/// </summary>
		string OperatingSystemInfo { get; }
	}
}
